import {BrowserModule} from '@angular/platform-browser';
import {NgModule} from '@angular/core';
import {RouterModule, Routes} from '@angular/router';
import {FormsModule, ReactiveFormsModule} from '@angular/forms';
import {MatCardModule} from '@angular/material/card';
import {MatAutocompleteModule} from '@angular/material/autocomplete';
import {LocationStrategy, HashLocationStrategy} from '@angular/common';

import {AppComponent} from './app.component';
import {FooterCompComponent} from './components/footer-comp/footer-comp.component';
import {NavCompComponent} from './components/nav-comp/nav-comp.component';

import {MatButtonModule, MatCheckboxModule, MatTableModule} from '@angular/material';
import {MatSidenavModule} from '@angular/material/sidenav';
import {BrowserAnimationsModule} from '@angular/platform-browser/animations';
import {MatIconModule} from '@angular/material/icon';
import {MatInputModule} from '@angular/material/input';
import {AgmCoreModule} from '@agm/core';
import {AgmSnazzyInfoWindowModule} from '@agm/snazzy-info-window';

import {HttpClientModule} from '@angular/common/http';
import {MapaCompComponent} from './components/mapa-comp/mapa-comp.component';
import {InformacioComponent} from './routes/informacio/informacio.component';
import {RegistreComponent} from './routes/registre/registre.component';
import {LoginComponent} from './routes/login/login.component';
import {HomeComponent} from './routes/home/home.component';
import {ContactarComponent} from './routes/contactar/contactar.component';
import {BackofficeComponent} from './routes/backoffice/backoffice.component';
import {ConfiguracioComponent} from './routes/backoffice/configuracio/configuracio.component';
import {PuntsProposatsComponent} from './routes/backoffice/punts-proposats/punts-proposats.component';
import {AfegeixComponent} from './routes/backoffice/afegeix/afegeix.component';
import {RevisaComponent} from './routes/backoffice/revisa/revisa.component';
import {DetallComponent} from './routes/detall/detall.component';
import {LlistatResultatsComponent} from './components/llistat-resultats/llistat-resultats.component';
import {ResultatElementComponent} from './components/resultat-element/resultat-element.component';
import {DeaProximComponent} from './components/dea-proxim/dea-proxim.component';
import {AdministracioComponent} from './routes/backoffice/administracio/administracio.component';
import {PuntComponent} from './routes/backoffice/administracio/punt/punt.component';
import {UsuarisComponent} from './routes/backoffice/administracio/usuaris/usuaris.component';
import {PoblacionsComponent} from './routes/backoffice/administracio/poblacions/poblacions.component';
import {Ng2SmartTableModule} from 'ng2-smart-table';
import {PuntService} from './services/punt-service';
import {PoblacioService} from './services/poblacio-service';
import {UserService} from './services/user-service';
import {MatSelectModule} from '@angular/material/select';
import { RecompteComponent } from './routes/backoffice/revisa/recompte/recompte.component';
import { ComentarisComponent } from './routes/backoffice/revisa/comentaris/comentaris.component';
import { AdminComentarisComponent } from './routes/backoffice/administracio/comentaris/comentaris.component';

const appRoutes: Routes = [
  {path: '', redirectTo: '/inici', pathMatch: 'full'},
  {path: 'inici', component: HomeComponent},
  {path: 'informacio', component: InformacioComponent},
  {path: 'contactar', component: ContactarComponent},
  {path: 'afegeix', component: AfegeixComponent},
  {path: 'revisa', component: RevisaComponent},
  {path: 'punts-proposats/:id', component: PuntsProposatsComponent},
  {path: 'registre', component: RegistreComponent},
  {path: 'accedir', component: LoginComponent},
  {path: 'configuracio', component: ConfiguracioComponent},
  {path: 'detall/:id', component: DetallComponent},
  {path: 'admin', component: AdministracioComponent},
  {path: 'admin/punts', component: PuntComponent},
  {path: 'admin/usuaris', component: UsuarisComponent},
  {path: 'admin/poblacions', component: PoblacionsComponent},
  {path: 'admin/comentaris', component: AdminComentarisComponent},

];

@NgModule({
  declarations: [
    AppComponent,
    FooterCompComponent,
    NavCompComponent,
    MapaCompComponent,
    InformacioComponent,
    RegistreComponent,
    LoginComponent,
    HomeComponent,
    ContactarComponent,
    BackofficeComponent,
    ConfiguracioComponent,
    PuntsProposatsComponent,
    AfegeixComponent,
    RevisaComponent,
    DetallComponent,
    LlistatResultatsComponent,
    ResultatElementComponent,
    DeaProximComponent,
    AdministracioComponent,
    PuntComponent,
    UsuarisComponent,
    PoblacionsComponent,
    RecompteComponent,
    ComentarisComponent,
    AdminComentarisComponent
  ],
  imports: [
    MatButtonModule,
    MatCheckboxModule,
    BrowserModule,
    HttpClientModule,
    MatSidenavModule,
    BrowserAnimationsModule,
    MatIconModule,
    MatInputModule,
    MatAutocompleteModule,
    MatTableModule,
    MatSelectModule,
    RouterModule.forRoot(appRoutes),
    AgmCoreModule.forRoot({
      apiKey: 'AIzaSyD3sUR9jjJCmeCJsyRpvrJfA8Kau9f0flA'
    }),
    AgmSnazzyInfoWindowModule,
    FormsModule,
    ReactiveFormsModule,
    MatCardModule,
    Ng2SmartTableModule
  ],
  exports: [
    MatTableModule
  ],
  providers: [
    {provide: LocationStrategy, useClass: HashLocationStrategy},
    PuntService,
    PoblacioService,
    UserService
    ],
  bootstrap: [AppComponent, FooterCompComponent, NavCompComponent]
})

export class AppModule {
}
