import {Component, OnInit} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {PuntModel} from '../../model/punt-model';
import {PuntService} from '../../services/punt-service';

@Component({
  selector: 'app-dea-proxim',
  templateUrl: './dea-proxim.component.html',
  styleUrls: ['./dea-proxim.component.css']
})
export class DeaProximComponent implements OnInit {

  punts: PuntModel[];
  lat: number;
  lng: number;
  visible: Boolean = true;

  constructor(private http: HttpClient, private pservice: PuntService) {
  }

  ngOnInit() {
    // Si no es el primer cop que visualitzem en una sessió el dea més pròxim, eliminem l'element.
    // Si no, mostrem el mapa amb els punts.
    // Si, el navegador es edge, ho fet agafant la ubicació de l'usuari, si no, posem una ubicació falsa.
    if (sessionStorage.getItem('proxim')) {
      this.removeElement();
    } else {
      if (navigator.userAgent.toLowerCase().indexOf('edge') > -1) {
        if (navigator.geolocation) {
          navigator.geolocation.getCurrentPosition(position => {
            this.lat = position.coords.latitude;
            this.lng = position.coords.longitude;
            this.pservice.getNearPoint(this.lat, this.lng).subscribe(response => {
              this.punts = response;
            });
          });
        } else {
          this.lat = 41.984200;
          this.lng = 2.823900;
          this.pservice.getNearPoint(this.lat, this.lng).subscribe(response => {
            this.punts = response;
          });
        }
      } else {
        this.lat = 41.984200;
        this.lng = 2.823900;
        this.pservice.getNearPoint(this.lat, this.lng).subscribe(response => {
          this.punts = response;
        });
      }
      sessionStorage.setItem('proxim', 'proxim');
    }
  }
  removeElement() {
    this.visible = false;
  }
}
