import {Component, Input, OnInit, OnChanges, SimpleChanges} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {PuntModel} from '../../model/punt-model';
import {PuntService} from '../../services/punt-service';

@Component({
  selector: 'app-llistat-resultats',
  templateUrl: './llistat-resultats.component.html',
  styleUrls: ['./llistat-resultats.component.css']
})
export class LlistatResultatsComponent implements OnInit {

  @Input() distance;

  punts: PuntModel[];
  lat: number;
  lng: number;
  error = false;

  constructor(public http: HttpClient, private pservice: PuntService) {
  }

  ngOnInit() {
    if (sessionStorage.getItem('lat')) {
      this.lat = Number(sessionStorage.getItem('lat'));
      this.lng = Number(sessionStorage.getItem('lon'));
      this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
        this.punts = response;
        this.error = false;
      }, error => this.error = true);
    } else if (navigator.userAgent.toLowerCase().indexOf('edge') > -1) {
      if (navigator.geolocation) {
        navigator.geolocation.getCurrentPosition(position => {
          this.lat = position.coords.latitude;
          this.lng = position.coords.longitude;
          this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
            this.punts = response;
            this.error = false;
          }, error => this.error = true);
        });
      } else {
        this.lat = 41.984200;
        this.lng = 2.823900;
        this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
          this.punts = response;
          this.error = false;
        }, error => this.error = true);
      }
    } else {
      this.lat = 41.984200;
      this.lng = 2.823900;
      this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
        this.punts = response;
        this.error = false;
      }, error => this.error = true);
    }
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.lat) {
      this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
        this.punts = response;
        this.error = false;
      }, error => this.error = true);
    }
  }
}
