import {Component, OnInit, Input, OnChanges, SimpleChanges, ChangeDetectionStrategy} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {PuntModel} from '../../model/punt-model';
import {PuntService} from '../../services/punt-service';

@Component({
  selector: 'app-mapa-comp',
  templateUrl: './mapa-comp.component.html',
  changeDetection: ChangeDetectionStrategy.Default
})
export class MapaCompComponent implements OnInit {

  @Input() height;
  @Input() inp_lat;
  @Input() inp_lon;

  distance = 30;
  punts: PuntModel[];
  zoom = 14;
  lat: number;
  lng: number;

  constructor(public http: HttpClient, private pservice: PuntService) {
  }

  ngOnInit() {
    if (sessionStorage.getItem('lat')) {
      this.lat = Number(sessionStorage.getItem('lat'));
      this.lng = Number(sessionStorage.getItem('lon'));
      this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
        this.punts = response;
      });
    } else if (navigator.userAgent.toLowerCase().indexOf('edge') > -1) {
      if (navigator.geolocation) {
        navigator.geolocation.getCurrentPosition(position => {
          this.lat = position.coords.latitude;
          this.lng = position.coords.longitude;
          this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
            this.punts = response;
          });
        });
      } else {
        this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
          this.punts = response;
        });
      }
    } else {
      this.lat = 41.984200;
      this.lng = 2.823900;
      this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
        this.punts = response;
      });
    }
  }

  ngOnChanges(changes: SimpleChanges) {
    if (this.lat) {
      this.pservice.getPoints(this.lat, this.lng, this.distance).subscribe(response => {
        this.punts = response;
      });
    }
  }
}
