import { Component, OnInit } from '@angular/core';
import {Location} from '@angular/common';
import {HttpClient} from '@angular/common/http';
import {PoblacioModel} from '../../../../model/poblacio-model';
import {PoblacioService} from '../../../../services/poblacio-service';

@Component({
  selector: 'app-poblacions',
  templateUrl: './poblacions.component.html'
})
export class PoblacionsComponent implements OnInit {

  poblacions: PoblacioModel[];
  settings = {
    add: {
      confirmCreate: true,
      addButtonContent: 'Afegir',
      createButtonContent: 'Crear',
      cancelButtonContent: 'Cancelar'
    },
    edit: {
      confirmSave: true,
      editButtonContent: 'Editar',
      saveButtonContent: 'Guardar',
      cancelButtonContent: 'Cancelar'
    },
    actions: {
      columnTitle: 'Accions',
      delete: false,
      position: 'right'
    },
    columns: {
      id: {
        title: 'ID',
        editable: false,
        addable: false
      },
      nom: {
        title: 'Nom'
      },
      latitud: {
        title: 'Latitud'
      },
      longitud: {
        title: 'Longitud'
      }
    }
  };

  constructor(private _location: Location, private http: HttpClient, private poservice: PoblacioService) { }

  ngOnInit() {
    this.poservice.getAllPoblacions().subscribe(response => {
      this.poblacions = response;
    });
  }

  goBack() {
    this._location.back();
  }

  onSaveConfirm(event) {
    if (window.confirm('Estas segur que vols modificar aquesta població?')) {
      event.confirm.resolve(event.newData);
      const pop = event.newData;
      this.poservice.updatePopulation(pop).subscribe(resolve => console.log('Població modificada!'));
    } else {
      event.confirm.reject();
    }
  }

  onCreateConfirm(event) {
    if (window.confirm('Estas segur que vols afegir una població nova?')) {
      event.confirm.resolve(event.newData);
      const pop = event.newData;
      this.poservice.createPopulation(pop).subscribe(resolve => console.log('Població creada!'));
    } else {
      event.confirm.reject();
    }
  }

}
