import {Component, OnInit} from '@angular/core';
import {Location} from '@angular/common';
import {PuntService} from '../../../../services/punt-service';
import {PuntModel} from '../../../../model/punt-model';
import {UserModel} from '../../../../model/user-model';
import {UserService} from '../../../../services/user-service';
import {PoblacioService} from '../../../../services/poblacio-service';
import {PoblacioModel} from '../../../../model/poblacio-model';

@Component({
  selector: 'app-punt',
  templateUrl: './punt.component.html'
})
export class PuntComponent implements OnInit {

  punts: PuntModel[];
  usersList: UserModel[];
  populationList: PoblacioModel[];
  settings = {
    delete: {
      confirmDelete: true,
      deleteButtonContent: 'Suprimir'
    },
    add: {
      confirmCreate: true,
      addButtonContent: 'Afegir',
      createButtonContent: 'Crear',
      cancelButtonContent: 'Cancelar'
    },
    edit: {
      confirmSave: true,
      editButtonContent: 'Editar',
      saveButtonContent: 'Guardar',
      cancelButtonContent: 'Cancelar'
    },
    actions: {
      columnTitle: 'Accions',
      position: 'right'
    },
    columns: {
      id: {
        title: 'ID',
        editable: false,
        addable: false
      },
      latitud: {
        title: 'Latitud'
      },
      longitud: {
        title: 'Longitud'
      },
      carrer: {
        title: 'Carrer'
      },
      cp: {
        title: 'Codi Postal'
      },
      validat: {
        title: 'Validat',
        filter: {
          type: 'checkbox',
          config: {
            true: '1',
            false: '0'
          }
        },
        editor: {
          type: 'checkbox',
          config: {
            true: '1',
            false: '0'
          }
        }
      },
      poblacio: {
        title: 'Població',
        editable: false,
        addable: false,
        filter: false
      },
      id_poblacio: {
        title: 'ID Població'
      },
      usuari: {
        title: 'Usuari',
        editable: false,
        addable: false,
        filter: false
      },
      id_usuari: {
        title: 'ID Usuari'
      }
    }
  };


  constructor(private _loc: Location, private pservice: PuntService, private uservice: UserService, private poservice: PoblacioService) {
  }

  ngOnInit() {
    this.pservice.getAllPointsBackoffice().subscribe(response => {
      this.punts = response;
    });
    this.uservice.getAllUsers().subscribe( response => {
      this.usersList = response;
    });
    this.poservice.getAllPoblacions().subscribe( response => {
      this.populationList = response;
    });
  }

  goBack() {
    this._loc.back();
  }

  onDeleteConfirm(event) {
    if (window.confirm('Estas segur que el vols eliminar?')) {
      event.confirm.resolve(event.newData);
      const punt = event.data;
      this.pservice.deletePoint(punt).subscribe(resolve => console.log('punt eliminat!'));
    } else {
      event.confirm.reject();
    }
  }

  onSaveConfirm(event) {
    if (window.confirm('Estas segur que vols modificar aquest punt?')) {
      event.confirm.resolve(event.newData);
      const punt = event.newData;
      this.pservice.updatePoint(punt).subscribe(resolve => console.log('punt modificat!'));
    } else {
      event.confirm.reject();
    }
  }

  onCreateConfirm(event) {
    if (window.confirm('Estas segur que vols afegir un punt nou?')) {
      event.confirm.resolve(event.newData);
      const punt = event.newData;
      this.pservice.createPoint(punt).subscribe(resolve => console.log('punt creat!'));
    } else {
      event.confirm.reject();
    }
  }
}
