import {Injectable} from '@angular/core';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {PuntModel} from '../model/punt-model';
import {Observable} from 'rxjs/Observable';
import {CommentModel} from '../model/comment-model';

@Injectable()
export class PuntService {
  private headers = new HttpHeaders({'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8'});

  constructor(private http: HttpClient) {
  }

  getNearPoint(lat, lon): Observable<PuntModel[]> {
    return this.http.get('http://deacatalunya.cat/deacatalunya/getNearPoint.php?lat=' + lat + '&lon=' + lon)
      .map((res => {
        return res as PuntModel[];
      }));
  }

  getPoints(lat, lon, distance): Observable<PuntModel[]> {
    return this.http.get('http://deacatalunya.cat/deacatalunya/getPointsList.php?lat=' + lat +
      '&lon=' + lon + '&dist=' + distance)
      .map((res => {
        return res as PuntModel[];
      }));
  }

  getAllPointsBackoffice(): Observable<PuntModel[]> {
    return this.http.get('http://deacatalunya.cat/deacatalunya/getAllPoints.php')
      .map((res => {
      return res as PuntModel[];
    }));
  }

  getNoValidatedPoints(): Observable<PuntModel[]> {
    return this.http.get('http://deacatalunya.cat/deacatalunya/getNoValidatedPoints.php')
      .map((res => {
        return res as PuntModel[];
      }));
  }

  getPointComments(id): Observable<CommentModel[]> {
    return this.http.get('http://deacatalunya.cat/deacatalunya/getPointComments.php?id=' + id)
      .map((res => {
        return res as CommentModel[];
      }));
  }

  getAllComments(): Observable<CommentModel[]> {
    return this.http.get('http://deacatalunya.cat/deacatalunya/getAllComments.php')
      .map((res => {
        return res as CommentModel[];
      }));
  }

  getPoint(id): Observable<PuntModel> {
    return this.http.get('  http://deacatalunya.cat/deacatalunya/getPoint.php?id=' + id)
      .map((res => {
        return res as PuntModel;
      }));
  }

  createPoint(point): Observable<object> {
    const url = 'http://deacatalunya.cat/deacatalunya/createPoint.php';
    return this.http.post(url, point, {headers: this.headers})
      .map(res => {
        return res;
      });
  }

  updatePoint(point): Observable<object> {
    const url = 'http://deacatalunya.cat/deacatalunya/updatePoint.php';
    return this.http.post(url, point, {headers: this.headers})
      .map(res => {
        return res;
      });
  }

  updateComment(comment): Observable<object> {
    const url = 'http://deacatalunya.cat/deacatalunya/updateComment.php';
    return this.http.post(url, comment, {headers: this.headers})
      .map(res => {
        return res;
      });
  }

  deletePoint(point): Observable<object> {
    const url = 'http://deacatalunya.cat/deacatalunya/deletePoint.php';
    return this.http.post(url,  point, {headers: this.headers})
      .map(res => {
        return res;
        });
  }

  deleteComment(comment): Observable<object> {
    const url = 'http://deacatalunya.cat/deacatalunya/deleteComment.php';
    return this.http.post(url,  comment, {headers: this.headers})
      .map(res => {
        return res;
      });
  }
}
